@@ -1,7 +1,7 @@
 '''Este é o módulo "nester.py", e fornece uma função chamada print_lol()
 que imprime listas que podem ou não incluir listas aninhadas.'''
 
-def print_lol(the_list, level):
+def print_lol(the_list, level = 0):
 	'''Esta função requer um argumento posicional chamado "the_list", que é
 	qualquer lista Python(de possíveis listas aninhadas). Cada item de dados na
 	lista fornecida é(recursivamente) impresso na tela em sua própria linha.
